:mod:`Fractions` --- Nombres rationnels
=======================================
Le module :mod:`Fractions` définit la classe :class:`Fractions` qui permet de
faire des calculs détaillés avec des nombres en écriture fractionnaire.

Un objet :class:`Fractions` est construit à partir de son numérateur et son
dénominateur.

.. automodule:: pyromaths.classes.Fractions
    :members:
    :special-members:
..    :private-members:
      :undoc-members:
      :show-inheritance:
